<?php
// Copyright (c) 2000-2013 Synology Inc. All rights reserved.


class SYNO_COMMON {

	/**
	 * Exception handler to print info in JSON.
	 */
	public static function showException($config, $data)
	{
		print str_replace('\\/', '/', json_encode($data, JSON_HEX_QUOT));
	}

	/**
	 * Convert special values (NULL, TRUE, FALSE, integer) in @data.
	 */
	private static function normalizeConfig(&$data)
	{
		foreach ($data as $key => $value) {
			if (is_array($value)) {
				SYNO_COMMON::normalizeConfig($data[$key]);
			} else if ($value === 'NULL' or $value === 'null') {
				$data[$key] = NULL;
			} else if ($value === 'TRUE' or $value === 'true') {
				$data[$key] = TRUE;
			} else if ($value === 'FALSE' or $value === 'false') {
				$data[$key] = FALSE;
			} else if (FALSE !== filter_var($value, FILTER_VALIDATE_INT)) {
				$data[$key] = (int)$value;
			}
		}
	}

	/**
	 * Parse @filename (in format of sections with key-value pairs) and put result into @meta.
	 * names of sections are treated as key for @meta. Values are treated as strings except
	 * some special values (NULL, TRUE, FALSE) will be converted.
	 *
	 * @param filename	[IN] Input filename for parsing
	 * @param meta		[OUT] Parsed result will be merged this it
	 *
	 * @return
	 * 	0: On success
	 * 	-1: On error
	 */
	public static function loadConfig($filename, &$meta)
	{
		if (!is_file($filename)) {
			return -1;
		}
		$data = parse_ini_file($filename, TRUE, INI_SCANNER_RAW);
		SYNO_COMMON::normalizeConfig($data);
		$meta = array_merge($meta, $data);
		return 0;
	}

	/**
	 * Convert global variables and stdin to PHP's pre-defined variables.
	 * Includes $_GET, $_POST, $_COOKIE, $_REQUEST.
	 */
	public static function resolveEnvVar()
	{
		parse_str($_SERVER['QUERY_STRING'], $_GET);
		parse_str($_SERVER['SYNO_POST_STRING'], $_POST);
		parse_str(str_replace(';', '&', $_SERVER['HTTP_COOKIE']), $_COOKIE);
		$_REQUEST = array_merge($_GET, $_POST);
	}
}

?>
